# This script will run another copy of the invoking shell in
# in a pipeline monitor it to make sure it has not crashed
# or simply gone into an infinite loop.

set debug 0

set file run.tcl
set fd [open $file w]

puts $fd "cd \"[pwd]\""
puts $fd "set argc \"$argc\""
puts $fd [list set argv $argv]
puts $fd "set builddir \"$builddir\""
puts $fd "set srcdir \"$srcdir\""
puts $fd "set host \"$host\""
puts $fd "source \"[file join $srcdir src svntest.tcl]\""

close $fd

if {$debug} {
    puts "<SCRIPT> : \{[exec cat $file]\} </SCRIPT>"
}


# Open up a file to log test output. Print output from a test
# run to stdout and to the log file. We don't want to do this
# in the test itself because of the recovery case, we don't
# want the output from a recovered run to overwrite the output
# from the first run. That would require some more work
# rewriting tcltest.

set log_dir [file join $builddir logging]
if {! [file isdirectory $log_dir]} {
    file mkdir $log_dir
}

# FIXME: The host.out get toasted when running
# a non-test subcommand like `snvtest commit-prep`
# We would need to do the append check thing
# inside tcltest to really fix this.

set out_file [file join $log_dir host.out]
set out_fd [open $out_file w]



set shell [info nameofexecutable]

set subprocess_exit_ok 0

while {! $subprocess_exit_ok} {

set fd [open "| $shell $file 2>@stdout"]
fconfigure $fd -buffering line


# FIXME: Need to set pipe to async so that we can
# timeout an individual test. Need to test the
# size of the log file to see if it changed during
# the timeout interval. We might also want to
# keep a file that stores the current subprocess
# PID around so that we could hit it with a signal
# in case the subprocess went into an infinite loop.

while {[gets $fd var] != -1} {
    if {$debug} {
        puts $out_fd $var
        puts "READ \"$var\""
    } else {
        puts $out_fd $var
        puts $var
    }
}

# FIXME: The crashtest driver has a nasty habit of
# going into an infinite loop in the case where a
# Tcl error is raised in the subcommand. Is there
# any way we could check for that condition and
# not continue to run when we find a Tcl error?

if {[catch {close $fd} err]} {
    if {$debug} {
        puts "Subprocess: exit error"
    }
    set subprocess_exit_ok 0
} else {
    if {$debug} {
        puts "Subprocess: exit ok"
    }
    set subprocess_exit_ok 1
}

}

if {$debug} {
    puts "DONE with crashtest.tcl"
}

file delete $file

close $out_fd

exit 0
