# This set of procs is intended to be used by the
# test suite implementation.
# -----------------------------------------------


# Get a list of subdirectories WRT the current directory
# or the current dir in the src tree

proc _subdirectories { {insrcdir 0} } {
    global srcdir

    set here [pwd]

    if {$insrcdir} {
        set src_cwd [file join $srcdir [_relative_pwd]]
        debug "src_cwd is $src_cwd"
        cd $src_cwd
    }

    set all [glob -nocomplain *]
    set dirs {}
    foreach file $all {
        if {[file isdirectory $file]} {
            # Skip known bad subdirectories
            switch -- $file {
                SVN -
                CVS -
                RCS {
                    continue
                }
            }
            lappend dirs [file join $here $file]
        }
    }

    if {$insrcdir} {
        cd $here
    }

    set sorted [lsort -dictionary $dirs]
    debug "sorted subdirs are \{$sorted\}"
    return $sorted
}


# Get the working directory relative to
# the builddir.
#
# For example:
# /.../svntest/tests/noggy/one -> tests/noggy/one

proc _relative_pwd { } {
    global builddir

    set curdir [file split [pwd]]
    set homesplit [file split $builddir]
    set homesplit_len [llength $homesplit]

    debug "curdir is \{$curdir\}"
    debug "homesplit is \{$homesplit\}, len is $homesplit_len"

    set len_m1 [expr {$homesplit_len - 1}]
    if {[lrange $homesplit 0 $len_m1] !=
        [lrange $curdir 0 $len_m1]} {
        error "cwd \"[pwd]\" is not in builddir \"$builddir\""
    }

    set shortdir [lrange $curdir $homesplit_len end]

    if {$shortdir == {}} {
        error "test should not be run out of home directory!"
    }

    debug "shortdir is \{$shortdir\}"
    return [eval {file join} $shortdir]
}


# Recurse into subdirectories and run the tests
# found in these subdirectories.

proc _dotests { } {
    global srcdir

    set rel [_relative_pwd]
    puts $rel

    set testfile [file join $srcdir $rel tests.tcl]
    debug "testfile is $testfile : exists [file exists $testfile]"

    if {[file exists $testfile]} {
        source $testfile
    }

    foreach subdir [_subdirectories 1] {
        _cd_build $subdir
        _dotests
    }

}



# Remove file generated on a
# previous run from the current dir.

proc _rm_generated_files {} {
  delete core *.core
}



# Recurse into subdirectories and
# remove any files that were
# generated on a previous run

proc _doclean { } {
    foreach subdir [_subdirectories] {
        set here [pwd]
        cd $subdir
        _doclean
        cd $here
    }

    _rm_generated_files

    set cleanup .cleanup
    if {[file exists $cleanup]} {
        foreach file [cat $cleanup] {
            if {[file isdirectory $file]} {
                # will only delete dir if empty
                if {[catch {file delete $file}]} {
                    #global errorInfo
                    #puts $errorInfo
                    #puts "glob results \"[glob $file/*]\""
                }
            } else {
                delete $file
            }
        }
        delete $cleanup
    }
}




# Change directories in the build directory.
# This could involve creating the directory
# if it does not already exist.

proc _cd_build { dir } {

    # If path starts with ../ then don't create the dir
    if {[string first ../ $dir] == -1} {
        if {! [file isdirectory $dir]} {
            debug "_cd_build mkdir $dir"
            file mkdir $dir
        }
    }

    debug "_cd_build $dir"
    cd $dir
}
