# This file contains procedures that are intended to
# be used by people writing test cases.
# --------------------------------------------------



# This is the primary interface to the test command.
# This proc will record the test case id and run
# the given commands via the tcltest::test cmd.

proc test { id args } {
    global testid
    set testid $id
    eval {tcltest::test $id} $args
}


# Check for an error while running the cmd.
# Return a list of the error status and
# the error status or return value of the cmd.

proc check_err { cmd } {
    list [catch $cmd err] $err
}



# Delete a file by name or pattern
# do not generate an error if it does not exist

proc delete { args } {

    foreach arg $args {
        if {[regexp {(\*|\?|\[|\])} $arg]} {
            foreach match [glob -nocomplain $arg] {
                #puts "deleting matched file \"$match\""
                file delete -force $match
            }
        } else {
            if {[file exists $arg]} {
                #puts "deleting arg \"$arg\""
                file delete -force $arg
            }
        }
    }

    return
}


# Return the contents of the given file, convert
# platform EOL to \n in the process.

proc cat { f } {
    set fd [open $f r]
    set buff [read $fd]
    close $fd
    return $buff
}



# Wrapper for the svn command itself. This
# wrapper will run the command and generate
# a Tcl error if the command does not exit
# with a status of 0. It will also fixup
# any output and rename core dumps so
# that they are unique to a test id.

proc svn { args } {
    if {[catch {eval exec svn $args} output]} {
        # If there was an error, make sure the
        # output of the exec does not contain
        # a stupid "child process exited abnormally"
        # string on the last line
        set lines [split $output \n]
        set last [lindex $lines end]
        if {$last == "child process exited abnormally"} {
            set output [join [lrange $lines 0 end-1] \n]
        }

        # See if svn dumped core
        set corefiles [glob -nocomplain core *.stackdump]
        if {$corefiles != {}} {
            if {[llength $corefiles] != 1} {
                error "found multiple core files \{$corefiles\}"
            }
            set core [lindex $corefiles 0]
            global testid
            set prefix $testid
            file rename $core $prefix.core
        }

        error $output
    }
    return $output
}


