# The svn help (usage) message

set help {usage: svn <subcommand> [options] [args]
Type "svn help <subcommand>" for help on a specific subcommand.

Most subcommands take file and/or directory arguments, recursing
on the directories.  If no arguments are supplied to such a
command, it will recurse on the current directory (inclusive) by
default.

Available subcommands:
   add (ad, new)
   checkout (co)
   commit (ci)
   delete (del, remove, rm)
   help (?, h)
   import (im, imp)
   proplist (plist, pl)
   propget (pget, pg)
   propset (pset, ps)
   status (stat, st)
   diff (df, di)
   update (up)

Subversion is a tool for revision control.
For additional information, see http://subversion.tigris.org
}


test client-help-1 { print help text } {
    check_err {svn help}
} [list 0 $help]

test client-help-2 { print help text } {
    check_err {svn}
} [list 1 $help]

test client-help-alias-1 { alias } {
    check_err {svn ?}
} [list 0 $help]

test client-help-alias-2 { alias } {
    check_err {svn h}
} [list 0 $help]



test client-help-unknown-1 { print help text } {
    check_err {svn someunknowncommand}
} [list 1 "$help\nunknown command: someunknowncommand"]




set help_add {add (ad, new): Add new files and directories to version control.
usage: add [TARGETS]
}

test client-help-add-1 { print help text on help add } {
    check_err {svn help add}
} [list 0 $help_add]

test client-help-add-2 { print help text on add without args } {
    check_err {svn add}
} [list 1 $help_add]

test client-help-add-alias-1 { alias } {
    check_err {svn help ad}
} [list 0 $help_add]

test client-help-add-alias-2 { alias } {
    check_err {svn help new}
} [list 0 $help_add]


set help_checkout {checkout (co): Check out a working directory from a repository.
usage: checkout REPOSPATH1 [REPOSPATH2 REPOSPATH3...]
}

test client-help-checkout-1 { print help text on help checkout } {
    check_err {svn help checkout}
} [list 0 $help_checkout]

test client-help-checkout-2 { print help text on checkout without args } {
    check_err {svn checkout}
} [list 1 $help_checkout]

test client-help-checkout-alias-1 { alias } {
    check_err {svn help co}
} [list 0 $help_checkout]


# FIXME : If a URL argument does not look like a URL, we should
# have a specific error message for that case! (like % svn co foo)



set help_commit {commit (ci): Commit changes from your working copy to the repository.
usage: commit [TARGETS]
}

test client-help-commit-1 { print help text on help commit } {
    check_err {svn help commit}
} [list 0 $help_commit]

test client-help-commit-alias-1 { alias } {
    check_err {svn help ci}
} [list 0 $help_commit]



set help_delete {delete (del, remove, rm): Remove files and directories from version control.
usage: delete [TARGETS]
}

test client-help-delete-1 { print help text on help delete } {
    check_err {svn help delete}
} [list 0 $help_delete]

test client-help-delete-2 { print help text on delete without args } {
    check_err {svn delete}
} [list 1 $help_delete]

test client-help-delete-alias-1 { alias } {
    check_err {svn help del}
} [list 0 $help_delete]

test client-help-delete-alias-2 { alias } {
    check_err {svn help remove}
} [list 0 $help_delete]

test client-help-delete-alias-3 { alias } {
    check_err {svn help rm}
} [list 0 $help_delete]



set help_status {status (stat, st): Print the status of working copy files and directories.
usage: status [TARGETS]
}

test client-help-status-1 { print help text on help status } {
    check_err {svn help status}
} [list 0 $help_status]

test client-help-status-alias-1 { alias } {
    check_err {svn help stat}
} [list 0 $help_status]

test client-help-status-alias-2 { alias } {
    check_err {svn help st}
} [list 0 $help_status]





set help_diff {diff (df, di): Display local file changes as contextual diffs.
usage: diff [TARGETS]
}

test client-help-diff-1 { print help text on help diff } {
    check_err {svn help diff}
} [list 0 $help_diff]

test client-help-diff-alias-1 { alias } {
    check_err {svn help df}
} [list 0 $help_diff]

test client-help-diff-alias-2 { alias } {
    check_err {svn help di}
} [list 0 $help_diff]





set help_update {update (up): Bring changes from the repository into the working copy.
usage: update [TARGETS]
}

test client-help-update-1 { print help text on help update } {
    check_err {svn help update}
} [list 0 $help_update]

test client-help-update-alias-1 { alias } {
    check_err {svn help up}
} [list 0 $help_update]





set help_proplist {proplist (plist, pl): List all properties for given files and directories.
usage: proplist [TARGETS]
}

test client-help-proplist-1 { print help text } {
    check_err {svn help proplist}
} [list 0 $help_proplist]

test client-help-proplist-alias-1 { alias } {
    check_err {svn help plist}
} [list 0 $help_proplist]

test client-help-proplist-alias-2 { alias } {
    check_err {svn help pl}
} [list 0 $help_proplist]




set help_propget {propget (pget, pg): Get the value of property PROPNAME on files and directories.
usage: propget PROPNAME [TARGETS]
}

test client-help-propget-1 { print help text } {
    check_err {svn help propget}
} [list 0 $help_propget]

test client-help-propget-2 { print help text } {
    check_err {svn propget}
} [list 1 $help_propget]

test client-help-propget-alias-1 { alias } {
    check_err {svn help pget}
} [list 0 $help_propget]


# FIXME: How would 1 argument for PROPNAME compined
# with a -valfile option be handled?

set help_propset {propset (pset, ps): Set property PROPNAME to PROPVAL on files and directories.
usage: propset PROPNAME [PROPVAL | --valfile VALFILE] [TARGETS]
}

test client-help-propset-1 { print help text } {
    check_err {svn help propset}
} [list 0 $help_propset]

test client-help-propset-2 { print help text } {
    check_err {svn propset}
} [list 1 $help_propset]

test client-help-propset-3 { print help text } {
    check_err {svn propset PROPNAME}
} [list 1 $help_propset]


# FIXME: It is not really clear what should happen
# with these next two. The argument processing
# code in svn is currently commented out. Will
# we need a valid WC to test this argument parsing?

if 0 {
test client-help-propset-4 { print help text } {
    check_err {svn propset PROPNAME PROPVAL --valfile VALFILE}
} [list 1 $help_propset]

test client-help-propset-5 { print help text } {
    check_err {svn propset PROPNAME --valfile VALFILE PROPVAL}
} [list 1 $help_propset]
}


test client-help-propset-alias-1 { alias } {
    check_err {svn help pset}
} [list 0 $help_propset]

test client-help-propset-alias-2 { alias } {
    check_err {svn help ps}
} [list 0 $help_propset]




# Help will print usage test for multiple commands.

test client-help-multiple-1 { print help for each subcommand } {
    check_err {svn help add delete}
} [list 0 "$help_add\n$help_delete"]

